View source: R/tthoves_install.R
| tthoves_install | R Documentation |
{tthoves_install} checks whether TT Hoves is imported and registered.
If the font does not imported and registered, then the {{tthoves_install}} let you know that the font should be installed the computer. Once, the font installed the local instance, then {tthoves} will import fonts and register to the R.
tthoves_install()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.